==> inSilicoDb_2.0.1.tar.gz: inSilicoDb/man/getDatasetPlatformList.Rd <==
\name{getDatasetPlatformList}
\alias{getDatasetPlatformList}
\title{Get a list of (dataset, platform) tuples}
\description{
	Get list of all available dataset and platform tuples that satisfy all specified constraints (see Arguments).
}
\usage{
getDatasetPlatformList(...);
}
\arguments{
 \item{...}{Optional arguments can be passed to the function for more specific requests:
	\describe{
  	\item{\code{platform}}{The platform of the chip on which a measurement was done.
A platform is identified by its GEO accession code. If specified, only datasets on the given platform are returned.}
  	\item{\code{norm}}{Type of normalization to use when pre-processing a dataset. Possible values: "ORIGINAL", "FRMA"[1], "SCAN"[2] or "UPC"[3]. If specified, only datasets for which the given preprocessed data is available are returned.}
  	\item{\code{query}}{If specified, only datasets for which the query keyword appears in either the title or description of the dataset. typical example queries are 'Thyroid Cancer', 'Primary vs Metastasis', 'p53', etc.}
 	\item{\code{curated}}{If curated = TRUE is specified, only manually curated datasets will be returned. }
	}
  }
}
\value{
A list of dataset and platform tuples.
}
\examples{
length(getDatasetPlatformList());
## 7167
length(getDatasetPlatformList(platform = "GPL570"));
## 2717
length(getDatasetPlatformList(platform = "GPL570", norm = "FRMA"));
## 2406
length(getDatasetPlatformList(platform = "GPL570", norm = "FRMA", 
                              query = "Thyroid Cancer"));
## 5
getDatasetPlatformList(platform = "GPL570", norm = "FRMA",
                       query = "Thyroid Cancer");
## [[1]]
## [1] "GSE6004" "GPL570" 
## 
## [[2]]
## [1] "GSE7307" "GPL570" 
## 
## [[3]]
## [1] "GSE32161" "GPL570"  
## 
## [[4]]
## [1] "GSE29265" "GPL570"  
## 
## [[5]]
## [1] "GSE2109" "GPL570" 
}
\seealso{
Use \code{\link{getDatasetList}} for the same functionality with a list of dataset identifiers as result.
}
\references{
[1] MN. McCall, BM. Bolstad, and RA. Irizarry, Frozen Robust Multi-Array Analysis (fRMA),
  \emph{Biostatistics}, vol. 11, no. 2, pp. 242-253 , 2008.
  
[2] SR. Piccolo, Y. Sun, JD. Campbell, ME. Lenburg, AH. Bild, and WE. Johnson, A single-sample microarray
  normalization method to facilitate personalized-medicine workflows, \emph{Genomics}, vol. 100, no. 6, pp. 337-344, 2012.
  
[3] SR. Piccolo, MR. Withers, OE. Francis, AH. Bild, and WE. Johnson, Multi-platform single-sample estimates of transcriptional activation, \emph{Proceedings of the National Academy of Sciences of the United States of America}, vol. 110, no. 44, pp. 17778-17783, 2013.
}

==> inSilicoDb_2.4.1.tar.gz: inSilicoDb/man/getDatasetPlatformList.Rd <==
\name{getDatasetPlatformList}
\alias{getDatasetPlatformList}
\title{Get a list of (dataset, platform) tuples}
\description{
	Get list of all available dataset and platform tuples that satisfy all specified constraints (see Arguments).
}
\usage{
getDatasetPlatformList(...);
}
\arguments{
 \item{...}{Optional arguments can be passed to the function for more specific requests:
	\describe{
  	\item{\code{platform}}{The platform of the chip on which a measurement was done.
A platform is identified by its GEO accession code. If specified, only datasets on the given platform are returned.}
  	\item{\code{norm}}{Type of normalization to use when pre-processing a dataset. Possible values: "ORIGINAL", "FRMA"[1], "SCAN"[2]. If specified, only datasets for which the given preprocessed data is available are returned.}
  	\item{\code{query}}{If specified, only datasets for which the query keyword appears in either the title or description of the dataset. typical example queries are 'Thyroid Cancer', 'Primary vs Metastasis', 'p53', etc.}
 	\item{\code{curated}}{If curated = TRUE is specified, only manually curated datasets will be returned. }
	}
  }
}
\value{
A list of dataset and platform tuples.
}
\examples{
length(getDatasetPlatformList());
## 7167
length(getDatasetPlatformList(platform = "GPL570"));
## 2717
length(getDatasetPlatformList(platform = "GPL570", norm = "FRMA"));
## 2406
length(getDatasetPlatformList(platform = "GPL570", norm = "FRMA", 
                              query = "Thyroid Cancer"));
## 5
getDatasetPlatformList(platform = "GPL570", norm = "FRMA",
                       query = "Thyroid Cancer");
## [[1]]
## [1] "GSE6004" "GPL570" 
## 
## [[2]]
## [1] "GSE7307" "GPL570" 
## 
## [[3]]
## [1] "GSE32161" "GPL570"  
## 
## [[4]]
## [1] "GSE29265" "GPL570"  
## 
## [[5]]
## [1] "GSE2109" "GPL570" 
}
\seealso{
Use \code{\link{getDatasetList}} for the same functionality with a list of dataset identifiers as result.
}
\references{
[1] MN. McCall, BM. Bolstad, and RA. Irizarry, Frozen Robust Multi-Array Analysis (fRMA),
  \emph{Biostatistics}, vol. 11, no. 2, pp. 242-253 , 2008.
  
[2] SR. Piccolo, Y. Sun, JD. Campbell, ME. Lenburg, AH. Bild, and WE. Johnson, A single-sample microarray
  normalization method to facilitate personalized-medicine workflows, \emph{Genomics}, vol. 100, no. 6, pp. 337-344, 2012.
}
